@@ -215,7 +215,9 @@ pub fn markup_html(s: &str) -> Result<Vec<HtmlBlock>, anyhow::Error> {
 }
 
 fn to_pango(t: &str) -> Option<(&'static str, &'static str)> {
-    let allowed = ["u", "del", "s", "em", "i", "strong", "b", "code", "a", "br"];
+    let allowed = [
+        "u", "del", "s", "em", "i", "strong", "b", "code", "a", "br", "sub", "sup",
+    ];
 
     if !allowed.contains(&t) {
         return None;
@@ -229,6 +231,8 @@ fn to_pango(t: &str) -> Option<(&'static str, &'static str)> {
         "del" | "s" => Some(("<s>", "</s>")),
         "u" => Some(("<u>", "</u>")),
         "code" => Some(("<tt>", "</tt>")),
+        "sub" => Some(("<sub>", "</sub>")),
+        "sup" => Some(("<sup>", "</sup>")),
         _ => None,
     }
 }
@@ -331,7 +335,7 @@ fn join_text_blocks(mut blocks: Vec<HtmlBlock>) -> Vec<HtmlBlock> {
 
     blocks.drain(..).fold(Vec::<HtmlBlock>::new(), |mut v, b| {
         let last = v.last();
-        if let (&Text(ref c), Some(Text(a))) = (&b, last) {
+        if let (Text(c), Some(Text(a))) = (&b, last) {
             let t = join_collapse_spaces(a, c);
             v.pop();
             v.push(Text(t));
@@ -749,6 +753,30 @@ mod test {
         }
     }
 
+    #[test]
+    fn html_non_block_tags() {
+        let text =
+            "How about some <u>underlined</u> <del>deleted</del> or <s>strikethrough</s> text? \
+             Maybe <em>emphasized</em>, <i>italic</i>, <strong>strong</strong> or <b>bold</b> text? \
+             Possibly a newline<br>with some more <code>code</code>? \
+             Finally some <sub>sub</sub> or <sup>super</sup> par lines!";
+
+        let blocks = markup_html(text);
+        assert!(blocks.is_ok());
+        let blocks = blocks.unwrap();
+        assert_eq!(blocks.len(), 1);
+        let HtmlBlock::Text(h) = &blocks[0] else {
+            panic!("No text block found")
+        };
+        assert_eq!(
+            h,
+            "How about some <u>underlined</u> <s>deleted</s> or <s>strikethrough</s> text? \
+             Maybe <i>emphasized</i>, <i>italic</i>, <b>strong</b> or <b>bold</b> text? \
+             Possibly a newline\nwith some more <tt>code</tt>? \
+             Finally some <sub>sub</sub> or <sup>super</sup> par lines!"
+        );
+    }
+
     #[test]
     fn codeblock_empty_whitespace() {
         let text = "
